@@ -4,7 +4,7 @@ use warnings;
 package YAML::PP;
 use B;
 
-our $VERSION = '0.007_002'; # TRIAL VERSION
+our $VERSION = '0.008_001'; # TRIAL VERSION
 
 use base 'Exporter';
 our @EXPORT_OK = qw/ Load LoadFile Dump DumpFile /;
@@ -86,6 +86,7 @@ sub load_file {
         require YAML::PP::Loader;
         $loader = YAML::PP::Loader->new(
             schema => $self->schema,
+            parser => $self->parser,
         );
         $self->loader($loader);
     }
@@ -627,6 +628,7 @@ Here are a few examples of what you can do right now:
     use YAML::PP qw/ Load Dump LoadFile DumpFile /;
     my @documents = Load($yaml);
     my @documents = LoadFile($filename);
+    my @documents = LoadFile($filehandle);
     my $yaml = = Dump(@documents);
     DumpFile($filename, @documents);
 
@@ -936,6 +938,7 @@ No function is exported by default.
     use YAML::PP qw/ LoadFile /;
     my $doc = LoadFile($file);
     my @docs = LoadFile($file);
+    my @docs = LoadFile($filehandle);
 
 =item Dump
 
