@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.007_002'; # TRIAL VERSION
+our $VERSION = '0.008_001'; # TRIAL VERSION
 
 use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
 use constant DEBUG => ($ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE}) ? 1 : 0;
@@ -71,6 +71,7 @@ sub set_event_stack { $_[0]->{event_stack} = $_[1] }
 sub rule { return $_[0]->{rule} }
 sub set_rule {
     my ($self, $name) = @_;
+    no warnings 'uninitialized';
     DEBUG and $self->info("set_rule($name)");
     $self->{rule} = $name;
 }
@@ -778,6 +779,28 @@ sub alias_event {
     $event_types->[-1] = $next_event{ $event_types->[-1] };
 }
 
+sub yaml_to_tokens {
+    my ($class, $type, $input) = @_;
+    my $yp = YAML::PP::Parser->new( receiver => sub {} );
+    my @docs = eval {
+        $type eq 'string' ? $yp->parse_string($input) : $yp->parse_file($input);
+    };
+    my $error = $@;
+
+    my $tokens = $yp->tokens;
+    my $next = $yp->lexer->next_tokens;
+    if ($error) {
+        push @$tokens, map { +{ %$_, name => 'ERROR' } } @$next;
+        my $remaining = $yp->reader->read;
+        $remaining = '' unless defined $remaining;
+        push @$tokens, { name => "ERROR", value => $remaining };
+    }
+    else {
+        push @$tokens, @$next;
+    }
+    return $error, $tokens;
+}
+
 sub event_to_test_suite {
     my ($self, $event) = @_;
     if (ref $event) {
@@ -893,20 +916,23 @@ sub debug_next_line {
 
 sub note {
     my ($self, $msg) = @_;
-    require Term::ANSIColor;
-    warn Term::ANSIColor::colored(["yellow"], "============ $msg"), "\n";
+    $self->_colorize_warn(["yellow"], "============ $msg");
 }
 
 sub info {
     my ($self, $msg) = @_;
-    require Term::ANSIColor;
-    warn Term::ANSIColor::colored(["cyan"], "============ $msg"), "\n";
+    $self->_colorize_warn(["cyan"], "============ $msg");
 }
 
 sub got {
     my ($self, $msg) = @_;
+    $self->_colorize_warn(["green"], "============ $msg");
+}
+
+sub _colorize_warn {
+    my ($self, $colors, $text) = @_;
     require Term::ANSIColor;
-    warn Term::ANSIColor::colored(["green"], "============ $msg"), "\n";
+    warn Term::ANSIColor::colored($colors, $text), "\n";
 }
 
 sub debug_event {
